import React from 'react';
import ReactDOM from 'react-dom';

const width = 960;
const height = 500;

const Ranunculus = ({ cx, cy, colorBase }) => (
  <g>
    {/* Ranunculus stem */}
    <line
      x1={cx}
      y1={cy}
      x2={cx}
      y2={cy + 50}
      stroke="green"
      strokeWidth="2"
    />
    {/* Ranunculus petals with added layers and variation */}
    {[...Array(10)].map((_, i) => (
      <ellipse
        key={i}
        cx={cx}
        cy={cy - (i % 5) * 3} // More layers with variation in placement
        rx={15 + (i % 2) * 3} // Variation in petal size
        ry={7 + (i % 2) * 2}
        fill={`hsl(${colorBase + i * 8}, 100%, ${70 - (i % 5) * 5}%)`} // Gradient effect by varying lightness
        transform={`rotate(${i * 18}, ${cx}, ${cy})`}
      />
    ))}
    {/* Ranunculus center */}
    <circle cx={cx} cy={cy} r="5" fill="orange" />
    {/* Leaves with more detail */}
    <ellipse
      cx={cx - 10}
      cy={cy + 30}
      rx="5"
      ry="15"
      fill="green"
      transform={`rotate(-20, ${cx - 10}, ${cy + 30})`}
    />
    <ellipse
      cx={cx + 10}
      cy={cy + 30}
      rx="5"
      ry="15"
      fill="green"
      transform={`rotate(20, ${cx + 10}, ${cy + 30})`}
    />
    {/* Dewdrop effect */}
    <circle
      cx={cx + 5}
      cy={cy - 10}
      r="2"
      fill="rgba(255, 255, 255, 0.8)"
    />
    {/* Shadow for depth */}
    <ellipse
      cx={cx}
      cy={cy + 52}
      rx="20"
      ry="5"
      fill="rgba(0,0,0,0.2)"
    />
  </g>
);

const Butterfly = ({ x, y }) => (
  <g>
    <circle cx={x} cy={y} r="3" fill="yellow" />
    <path
      d={`M${x} ${y} q10,-10 20,0 q-10,10 -20,0 M${x} ${y} q-10,-10 -20,0 q10,10 20,0`}
      fill="lightblue"
    />
  </g>
);

const SunriseBackground = () => (
  <rect
    x="0"
    y="0"
    width={width}
    height={height}
    fill="#87CEEB"
  />
);

const App = () => {
  const numberOfFlowers = 20; // Reduced number of flowers

  const ranunculusFlowers = Array.from({
    length: numberOfFlowers,
  }).map((_, i) => {
    const cx = (i % 5) * (width / 5) + 50; // Adjust for fewer flowers
    const cy = Math.floor(i / 5) * (height / 5) + 50;
    const colorBase = Math.random() * 360;
    return (
      <Ranunculus
        key={i}
        cx={cx}
        cy={cy}
        colorBase={colorBase}
      />
    );
  });

  // Adding animated butterflies
  const butterflies = Array.from({ length: 5 }).map(
    (_, i) => (
      <Butterfly
        key={i}
        x={Math.random() * width}
        y={Math.random() * height}
      />
    ),
  );

  return (
    <svg width={width} height={height}>
      <SunriseBackground />
      {ranunculusFlowers}
      {butterflies}
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
